@@ -83,24 +83,25 @@ recover.data.call = function(object, trms, na.action, data = NULL, params = NULL
         fcall$drop.unused.levels = TRUE
         fcall[[1L]] = as.name("model.frame")
         fcall$xlev = NULL # we'll ignore xlev
-        fcall$na.action = na.omit
-        ### I once had a reason to put one var on the left, but don't remember why
-        ### Now it messes up if there's a '$' in that term
-        #         if (length(vars) > 1) 
-        #             form = reformulate(vars[-1], response = vars[1])
-        #         else
+        # If we have an explicit list of cases to exclude, let everything through now
+        if (!is.null(na.action))
+            fcall$na.action = na.pass
+        else  # exclude incomplete cases
+            fcall$na.action = na.omit
         form = reformulate(vars)
         fcall$formula = update(trms, form)
         env = environment(trms)
         if (is.null(env)) 
             env = parent.frame()
         tbl = eval(fcall, env, parent.frame())
+        
+        # Now we can drop na.action's rows
         if (!is.null(na.action))
             tbl = tbl[-(na.action),  , drop=FALSE]
     }
     
     else
-        fcall$data = tbl[complete.cases(data), , drop=FALSE]
+        tbl = tbl[complete.cases(tbl), , drop=FALSE]
     
     attr(tbl, "call") = object # the original call
     attr(tbl, "terms") = trms
@@ -179,33 +180,47 @@ lsm.basis.merMod = function(object, trms, xlev, grid, vcov., ...) {
     else
         V = as.matrix(.my.vcov(object, vcov.))
     dfargs = misc = list()
+    
     if (lme4::isLMM(object)) {
-        pbdis = .lsm.is.true("disable.pbkrtest")
-        Nlim = get.lsm.option("pbkrtest.limit")
-        objN = lme4::getME(object, "N")
-        toobig = objN > Nlim
-        if (!pbdis && !toobig && requireNamespace("pbkrtest") && missing(vcov.)) {
-            dfargs = list(unadjV = V, 
-                adjV = pbkrtest::vcovAdj.lmerMod(object, 0))
-            V = as.matrix(dfargs$adjV)
-            tst = try(pbkrtest::Lb_ddf)
-            if(class(tst) != "try-error")
-                dffun = function(k, dfargs) pbkrtest::Lb_ddf (k, dfargs$unadjV, dfargs$adjV)
+        satdis = .lsm.is.true("disable.satterth")
+        if (!satdis) {
+            if (requireNamespace("lmerTest")) {
+                dfargs = list(object = object)
+                dffun = function(k, dfargs) lmerTest::calcSatterth(dfargs$object, k)$denom
+            }
             else {
+                message("Install package 'lmerTest' to obtain Satterthwaite degrees of freedom")
                 dffun = function(k, dfargs) NA
-                warning("To obtain d.f., install 'pbkrtest' version 0.4-1 or later")
             }
         }
         else {
-            if(!pbdis && !("pbkrtest" %in% row.names(installed.packages())))
-                message("Install package 'pbkrtest' to obtain bias corrections and degrees of freedom")
-            else if(toobig)
-                message("Note: Adjusted covariance and degrees-of-freedom calculations have been\n",
-                        "disabled because the number of observations exceeds ", Nlim, ".\n",
-                        "Standard errors and tests may be more biased than if they were adjusted.\n",
-                        "To enable adjustments, set lsm.options(pbkrtest.limit = ", objN, ") or larger,\n",
-                        "but be warned that this may result in large computation time and memory use.")
-            dffun = function(k, dfargs) NA
+            pbdis = .lsm.is.true("disable.pbkrtest")
+            Nlim = get.lsm.option("pbkrtest.limit")
+            objN = lme4::getME(object, "N")
+            toobig = objN > Nlim
+            if (!pbdis && !toobig && requireNamespace("pbkrtest") && missing(vcov.)) {
+                dfargs = list(unadjV = V, 
+                              adjV = pbkrtest::vcovAdj.lmerMod(object, 0))
+                V = as.matrix(dfargs$adjV)
+                tst = try(pbkrtest::Lb_ddf)
+                if(class(tst) != "try-error")
+                    dffun = function(k, dfargs) pbkrtest::Lb_ddf (k, dfargs$unadjV, dfargs$adjV)
+                else {
+                    dffun = function(k, dfargs) NA
+                    warning("To obtain d.f., install 'pbkrtest' version 0.4-1 or later")
+                }
+            }
+            else {
+                if(!pbdis && !("pbkrtest" %in% row.names(installed.packages())))
+                    message("Install package 'pbkrtest' to obtain bias corrections and degrees of freedom")
+                else if(toobig)
+                    message("Note: Adjusted covariance and degrees-of-freedom calculations have been\n",
+                            "disabled because the number of observations exceeds ", Nlim, ".\n",
+                            "Standard errors and tests may be more biased than if they were adjusted.\n",
+                            "To enable adjustments, set lsm.options(pbkrtest.limit = ", objN, ") or larger,\n",
+                            "but be warned that this may result in large computation time and memory use.")
+                dffun = function(k, dfargs) NA
+            }
         }
     }
     else if (lme4::isGLMM(object)) {
@@ -290,8 +305,11 @@ recover.data.lme = function(object, data, ...) {
     fcall = object$call
     if (!is.null(fcall$weights))
         fcall$weights = nlme::varWeights(object$modelStruct)
-    if(is.null(data)) # lme objects actually have the data, so use it!
+    if(is.null(data)) { # lme objects actually have the data, so use it!
         data = object$data
+        if (!is.null(object$na.action))
+            data = data[-object$na.action, , drop = FALSE]
+    }
     recover.data(fcall, delete.response(terms(object)), object$na.action, data = data, ...)
 }
 
